@@ -148,7 +148,7 @@ CmdFctType cmd_key_cmds[] =
     
 CmdFctType cmd_usr_cmds[]=
 {
-	{"ACS-S",  {"widget surroundings", 	NULL}},	
+/*	{"ACS-S",  {"widget surroundings", 	NULL}},	*/
 /*	{"Control_L",{"shutup", 		NULL}},*/
 	{NULL,	   {NULL}}
 };
